@@ -43,7 +43,7 @@ func runList(ctx context.Context, opt listOptions, args []string) error {
 	}
 	// Write the list of chunk IDs to STDOUT
 	for _, chunk := range c.Chunks {
-		fmt.Fprintln(stdout, chunk.ID)
+		fmt.Fprintln(stdout, chunk.ID.String())
 		// See if we're meant to stop
 		select {
 		case <-ctx.Done():
