@@ -13,7 +13,7 @@ type NoSuchObject struct {
 }
 
 func (e ChunkMissing) Error() string {
-	return fmt.Sprintf("chunk %s missing from store", e.ID)
+	return fmt.Sprintf("chunk %s missing from store", e.ID.String())
 }
 
 func (e NoSuchObject) Error() string {
@@ -27,7 +27,7 @@ type ChunkInvalid struct {
 }
 
 func (e ChunkInvalid) Error() string {
-	return fmt.Sprintf("chunk id %s does not match its hash %s", e.ID, e.Sum)
+	return fmt.Sprintf("chunk id %s does not match its hash %s", e.ID.String(), e.Sum.String())
 }
 
 // InvalidFormat is returned when an error occurred when parsing an archive file
